@@ -73,9 +73,9 @@ typedef void fil_space_t;
 #include <string.h>
 
 #ifdef UNIV_NONINL
-# include "fsp0fsp.inl"
-# include "mach0data.inl"
-# include "ut0rnd.inl"
+# include "fsp0fsp.ic"
+# include "mach0data.ic"
+# include "ut0rnd.ic"
 #endif
 
 #ifndef PRIuMAX
@@ -94,9 +94,10 @@ static my_bool do_leaf;
 static my_bool per_page_details;
 static ulint n_merge;
 extern ulong			srv_checksum_algorithm;
-static ulong physical_page_size;  /* Page size in bytes on disk. */
-static ulong logical_page_size;   /* Page size when uncompressed. */
+static ulint physical_page_size;  /* Page size in bytes on disk. */
+static ulint logical_page_size;   /* Page size when uncompressed. */
 ulong srv_page_size;
+ulong srv_page_size_shift;
 page_size_t			univ_page_size(0, 0, false);
 /* Current page number (0 based). */
 uint32_t		cur_page_num;
@@ -137,13 +138,10 @@ static ulong			write_check;
 struct innodb_page_type {
 	int n_undo_state_active;
 	int n_undo_state_cached;
-	int n_undo_state_to_free;
 	int n_undo_state_to_purge;
 	int n_undo_state_prepared;
 	int n_undo_state_other;
-	int n_undo_insert;
-	int n_undo_update;
-	int n_undo_other;
+	int n_undo;
 	int n_fil_page_index;
 	int n_fil_page_undo_log;
 	int n_fil_page_inode;
@@ -309,16 +307,16 @@ const page_size_t
 get_page_size(
 	byte*	buf)
 {
-	const ulint	flags = mach_read_from_4(buf + FIL_PAGE_DATA
+	const unsigned	flags = mach_read_from_4(buf + FIL_PAGE_DATA
 						 + FSP_SPACE_FLAGS);
 
-	const ulint	ssize = FSP_FLAGS_GET_PAGE_SSIZE(flags);
+	const ulong	ssize = FSP_FLAGS_GET_PAGE_SSIZE(flags);
 
-	if (ssize == 0) {
-		srv_page_size = UNIV_PAGE_SIZE_ORIG;
-	} else {
-		srv_page_size = ((UNIV_ZIP_SIZE_MIN >> 1) << ssize);
-	}
+	srv_page_size_shift = ssize
+		? UNIV_ZIP_SIZE_SHIFT_MIN - 1 + ssize
+		: UNIV_PAGE_SIZE_SHIFT_ORIG;
+
+	srv_page_size = 1U << srv_page_size_shift;
 
 	univ_page_size.copy_from(
 		page_size_t(srv_page_size, srv_page_size, false));
@@ -348,7 +346,7 @@ error_message(
 
 /***********************************************//*
  @param>>_______[in] name>_____name of file.
- @retval file pointer; file pointer is NULL when error occured.
+ @retval file pointer; file pointer is NULL when error occurred.
 */
 
 FILE*
@@ -432,13 +430,13 @@ open_file(
 						tablespace.
  @retval no. of bytes read.
 */
-ulong read_file(
+ulint read_file(
 	byte*	buf,
 	bool	partial_page_read,
-	ulong	physical_page_size,
+	ulint	physical_page_size,
 	FILE*	fil_in)
 {
-	ulong bytes = 0;
+	ulint bytes = 0;
 
 	DBUG_ASSERT(physical_page_size >= UNIV_ZIP_SIZE_MIN);
 
@@ -448,7 +446,7 @@ ulong read_file(
 		bytes = UNIV_ZIP_SIZE_MIN;
 	}
 
-	bytes += ulong(fread(buf, 1, physical_page_size, fil_in));
+	bytes += ulint(fread(buf, 1, physical_page_size, fil_in));
 
 	return bytes;
 }
@@ -851,7 +849,7 @@ parse_page(
 	uint32_t page_no, left_page_no, right_page_no;
 	ulint data_bytes;
 	bool is_leaf;
-	int size_range_id;
+	ulint size_range_id;
 
 	/* Check whether page is doublewrite buffer. */
 	if(skip_page) {
@@ -886,7 +884,7 @@ parse_page(
 
 			is_leaf = (!*(const uint16*) (page + (PAGE_HEADER + PAGE_LEVEL)));
 
-			if (file) {
+			if (page_type_dump) {
 				fprintf(file, "#::" UINT32PF "\t\t|\t\tIndex page\t\t\t|"
 					"\tindex id=%llu,", cur_page_num, id);
 
@@ -939,7 +937,7 @@ parse_page(
 				index.total_data_bytes += data_bytes;
 				index.pages_in_size_range[size_range_id] ++;
 			}
-		} else if (file) {
+		} else {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tEncrypted Index page\t\t\t|"
 				"\tkey_version " UINT32PF ",%s\n", cur_page_num, key_version, str);
 		}
@@ -950,31 +948,17 @@ parse_page(
 		page_type.n_fil_page_undo_log++;
 		undo_page_type = mach_read_from_2(page +
 				     TRX_UNDO_PAGE_HDR + TRX_UNDO_PAGE_TYPE);
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tUndo log page\t\t\t|",
 				cur_page_num);
 		}
-		if (undo_page_type == TRX_UNDO_INSERT) {
-			page_type.n_undo_insert++;
-			if (file) {
-				fprintf(file, "\t%s",
-					"Insert Undo log page");
-			}
-
-		} else if (undo_page_type == TRX_UNDO_UPDATE) {
-			page_type.n_undo_update++;
-			if (file) {
-				fprintf(file, "\t%s",
-					"Update undo log page");
-			}
-		}
-
+		page_type.n_undo++;
 		undo_page_type = mach_read_from_2(page + TRX_UNDO_SEG_HDR +
 						  TRX_UNDO_STATE);
 		switch (undo_page_type) {
 			case TRX_UNDO_ACTIVE:
 				page_type.n_undo_state_active++;
-				if (file) {
+				if (page_type_dump) {
 					fprintf(file, ", %s", "Undo log of "
 						"an active transaction");
 				}
@@ -982,23 +966,15 @@ parse_page(
 
 			case TRX_UNDO_CACHED:
 				page_type.n_undo_state_cached++;
-				if (file) {
+				if (page_type_dump) {
 					fprintf(file, ", %s", "Page is "
 						"cached for quick reuse");
 				}
 				break;
 
-			case TRX_UNDO_TO_FREE:
-				page_type.n_undo_state_to_free++;
-				if (file) {
-					fprintf(file, ", %s", "Insert undo "
-						"segment that can be freed");
-				}
-				break;
-
 			case TRX_UNDO_TO_PURGE:
 				page_type.n_undo_state_to_purge++;
-				if (file) {
+				if (page_type_dump) {
 					fprintf(file, ", %s", "Will be "
 						"freed in purge when all undo"
 					"data in it is removed");
@@ -1007,7 +983,7 @@ parse_page(
 
 			case TRX_UNDO_PREPARED:
 				page_type.n_undo_state_prepared++;
-				if (file) {
+				if (page_type_dump) {
 					fprintf(file, ", %s", "Undo log of "
 						"an prepared transaction");
 				}
@@ -1017,14 +993,14 @@ parse_page(
 				page_type.n_undo_state_other++;
 				break;
 		}
-		if(file) {
+		if(page_type_dump) {
 			fprintf(file, ", %s\n", str);
 		}
 		break;
 
 	case FIL_PAGE_INODE:
 		page_type.n_fil_page_inode++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tInode page\t\t\t|"
 				"\t%s\n",cur_page_num, str);
 		}
@@ -1032,7 +1008,7 @@ parse_page(
 
 	case FIL_PAGE_IBUF_FREE_LIST:
 		page_type.n_fil_page_ibuf_free_list++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tInsert buffer free list"
 				" page\t|\t%s\n", cur_page_num, str);
 		}
@@ -1040,7 +1016,7 @@ parse_page(
 
 	case FIL_PAGE_TYPE_ALLOCATED:
 		page_type.n_fil_page_type_allocated++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tFreshly allocated "
 				"page\t\t|\t%s\n", cur_page_num, str);
 		}
@@ -1048,7 +1024,7 @@ parse_page(
 
 	case FIL_PAGE_IBUF_BITMAP:
 		page_type.n_fil_page_ibuf_bitmap++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tInsert Buffer "
 				"Bitmap\t\t|\t%s\n", cur_page_num, str);
 		}
@@ -1056,7 +1032,7 @@ parse_page(
 
 	case FIL_PAGE_TYPE_SYS:
 		page_type.n_fil_page_type_sys++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tSystem page\t\t\t|"
 				"\t%s\n", cur_page_num, str);
 		}
@@ -1064,7 +1040,7 @@ parse_page(
 
 	case FIL_PAGE_TYPE_TRX_SYS:
 		page_type.n_fil_page_type_trx_sys++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tTransaction system "
 				"page\t\t|\t%s\n", cur_page_num, str);
 		}
@@ -1072,7 +1048,7 @@ parse_page(
 
 	case FIL_PAGE_TYPE_FSP_HDR:
 		page_type.n_fil_page_type_fsp_hdr++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tFile Space "
 				"Header\t\t|\t%s\n", cur_page_num, str);
 		}
@@ -1080,7 +1056,7 @@ parse_page(
 
 	case FIL_PAGE_TYPE_XDES:
 		page_type.n_fil_page_type_xdes++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tExtent descriptor "
 				"page\t\t|\t%s\n", cur_page_num, str);
 		}
@@ -1088,7 +1064,7 @@ parse_page(
 
 	case FIL_PAGE_TYPE_BLOB:
 		page_type.n_fil_page_type_blob++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tBLOB page\t\t\t|\t%s\n",
 				cur_page_num, str);
 		}
@@ -1096,7 +1072,7 @@ parse_page(
 
 	case FIL_PAGE_TYPE_ZBLOB:
 		page_type.n_fil_page_type_zblob++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tCompressed BLOB "
 				"page\t\t|\t%s\n", cur_page_num, str);
 		}
@@ -1104,7 +1080,7 @@ parse_page(
 
 	case FIL_PAGE_TYPE_ZBLOB2:
 		page_type.n_fil_page_type_zblob2++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tSubsequent Compressed "
 				"BLOB page\t|\t%s\n", cur_page_num, str);
 		}
@@ -1112,7 +1088,7 @@ parse_page(
 
 	case FIL_PAGE_PAGE_COMPRESSED:
 		page_type.n_fil_page_type_page_compressed++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tPage compressed "
 				"page\t|\t%s\n", cur_page_num, str);
 		}
@@ -1120,7 +1096,7 @@ parse_page(
 
 	case FIL_PAGE_PAGE_COMPRESSED_ENCRYPTED:
 		page_type.n_fil_page_type_page_compressed_encrypted++;
-		if (file) {
+		if (page_type_dump) {
 			fprintf(file, "#::" UINT32PF "\t\t|\t\tPage compressed encrypted "
 				"page\t|\t%s\n", cur_page_num, str);
 		}
@@ -1133,7 +1109,7 @@ parse_page(
 /**
 @param [in/out] file_name	name of the filename
 
-@retval FILE pointer if successfully created else NULL when error occured.
+@retval FILE pointer if successfully created else NULL when error occurred.
 */
 FILE*
 create_file(
@@ -1217,15 +1193,11 @@ print_summary(
 
 	fprintf(fil_out, "\n===============================================\n");
 	fprintf(fil_out, "Additional information:\n");
-	fprintf(fil_out, "Undo page type: %d insert, %d update, %d other\n",
-		page_type.n_undo_insert,
-		page_type.n_undo_update,
-		page_type.n_undo_other);
-	fprintf(fil_out, "Undo page state: %d active, %d cached, %d to_free, %d"
+	fprintf(fil_out, "Undo page type: %d\n", page_type.n_undo);
+	fprintf(fil_out, "Undo page state: %d active, %d cached, %d"
 		" to_purge, %d prepared, %d other\n",
 		page_type.n_undo_state_active,
 		page_type.n_undo_state_cached,
-		page_type.n_undo_state_to_free,
 		page_type.n_undo_state_to_purge,
 		page_type.n_undo_state_prepared,
 		page_type.n_undo_state_other);
@@ -1746,15 +1718,13 @@ int main(
 		ulint zip_size = page_size.is_compressed() ? page_size.logical() : 0;
 		logical_page_size = page_size.is_compressed() ? zip_size : 0;
 		physical_page_size = page_size.physical();
-		srv_page_size = page_size.logical();
 		bool is_compressed = FSP_FLAGS_HAS_PAGE_COMPRESSION(flags);
 
 		if (physical_page_size == UNIV_ZIP_SIZE_MIN) {
 			partial_page_read = false;
 		} else {
 			/* Read rest of the page 0 to determine crypt_data */
-			bytes = ulong(read_file(buf, partial_page_read, page_size.physical(), fil_in));
-
+			bytes = read_file(buf, partial_page_read, page_size.physical(), fil_in);
 			if (bytes != page_size.physical()) {
 				fprintf(stderr, "Error: Was not able to read the "
 					"rest of the page ");
